Index: include/v8-profiler.h |
diff --git a/include/v8-profiler.h b/include/v8-profiler.h |
index bcca65edbcab607196694d06e15b2464828f5253..2ec8aefad08b45c7d1d456146937462347b4535a 100644 |
--- a/include/v8-profiler.h |
+++ b/include/v8-profiler.h |
@@ -255,7 +255,11 @@ class V8EXPORT HeapGraphNode { |
kClosure = 5, // Function closure. |
kRegExp = 6, // RegExp. |
kHeapNumber = 7, // Number stored in the heap. |
- kNative = 8 // Native object (not from V8 heap). |
+ kNative = 8, // Native object (not from V8 heap). |
+ kArtificial = 9 // Artificial object, usualy used for grouping |
mnaganov (inactive)
2012/02/06 15:37:22
Agreed offline to renamed this to kSynthetic. And
|
+ // snapshot items together for reducing |
+ // postprocessing steps. |
+ // example - group of detached DOM trees. |
}; |
/** Returns node type (see HeapGraphNode::Type). */ |